"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.CCircle = exports.CSquare = exports.CBox = void 0;

var _vue = require("vue");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _vueSystem = require("@chakra-ui/vue-system");

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !(0, _vue.isVNode)(s);
}

/**
 * Box is the most abstract component on top of which other chakra
 * components are built. It renders a `div` element by default.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/box
 */
var CBox = (0, _vue.defineComponent)({
  name: 'CBox',
  props: {
    as: {
      type: [String, Object],
      "default": 'div'
    }
  },
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    return function () {
      return (0, _vue.createVNode)(_vueSystem.chakra.div, (0, _vue.mergeProps)({
        "as": props.as,
        "__label": "box"
      }, attrs), _isSlot(slots) ? slots : {
        "default": function _default() {
          return [slots];
        }
      });
    };
  }
});
/**
 * As a constraint, you can't pass size related props
 * Only `size` would be allowed
 */

exports.CBox = CBox;

/**
 * CSquare is the `CBox` component implemented as a square
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/box
 */
var CSquare = (0, _vue.defineComponent)({
  name: 'CSquare',
  props: {
    size: [Object, String, Number],
    centerContent: {
      type: [Boolean],
      "default": true
    }
  },
  setup: function setup(props, _ref2) {
    var slots = _ref2.slots,
        attrs = _ref2.attrs;
    var styles = (0, _vue.computed)(function () {
      return props.centerContent ? {
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center'
      } : {};
    });
    return function () {
      return (0, _vue.createVNode)(CBox, (0, _vue.mergeProps)({
        "__label": "square",
        "boxSize": props.size,
        "__css": (0, _extends2["default"])({}, styles.value, {
          flexShrink: 0,
          flexGrow: 0
        })
      }, attrs), _isSlot(slots) ? slots : {
        "default": function _default() {
          return [slots];
        }
      });
    };
  }
});
/**
 * CCircle is the `CBox` component implemented as a circle
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/box
 */

exports.CSquare = CSquare;
var CCircle = (0, _vue.defineComponent)({
  name: 'CCircle',
  setup: function setup(_, _ref3) {
    var slots = _ref3.slots,
        attrs = _ref3.attrs;
    return function () {
      return (0, _vue.createVNode)(CSquare, (0, _vue.mergeProps)({
        "__label": "circle",
        "borderRadius": "9999px"
      }, attrs), _isSlot(slots) ? slots : {
        "default": function _default() {
          return [slots];
        }
      });
    };
  }
});
exports.CCircle = CCircle;
//# sourceMappingURL=box.js.map