"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.CDivider = void 0;

var _vue = require("vue");

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _vueSystem = require("@chakra-ui/vue-system");

var _utils = require("@chakra-ui/utils");

var _vueUtils = require("@chakra-ui/vue-utils");

/**
 * Layout component used to visually separate content in a list or group.
 * It display a thin horizontal or vertical line, and renders a `hr` tag.
 *
 * @see Docs https://vue.chakra-ui.com/docs/data-display/divider
 */
var CDivider = (0, _vue.defineComponent)({
  name: 'CDivider',
  props: (0, _extends2["default"])({
    orientation: {
      type: [String],
      "default": 'horizontal'
    }
  }, _vueUtils.vueThemingProps),
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    var themingProps = (0, _vue.computed)(function () {
      return (0, _utils.filterUndefined)({
        colorScheme: props.colorScheme,
        variant: props.variant,
        size: props.size,
        styleConfig: props.styleConfig,
        orientation: props.orientation
      });
    });
    var styles = (0, _vueSystem.useStyleConfig)('Divider', themingProps.value);
    var _styles$value = styles.value,
        borderLeftWidth = _styles$value.borderLeftWidth,
        borderBottomWidth = _styles$value.borderBottomWidth,
        borderTopWidth = _styles$value.borderTopWidth,
        borderRightWidth = _styles$value.borderRightWidth,
        borderWidth = _styles$value.borderWidth,
        borderStyle = _styles$value.borderStyle,
        borderColor = _styles$value.borderColor,
        stylesRest = (0, _objectWithoutPropertiesLoose2["default"])(_styles$value, ["borderLeftWidth", "borderBottomWidth", "borderTopWidth", "borderRightWidth", "borderWidth", "borderStyle", "borderColor"]);
    var dividerStyle = (0, _vue.computed)(function () {
      var dividerStyles = {
        vertical: {
          borderLeftWidth: borderLeftWidth || borderRightWidth || borderWidth || '1px',
          height: '100%'
        },
        horizontal: {
          borderBottomWidth: borderBottomWidth || borderTopWidth || borderWidth || '1px',
          width: '100%'
        }
      };
      return dividerStyles[props.orientation];
    });
    return function () {
      return (0, _vue.createVNode)(_vueSystem.chakra.hr, {
        "aria-orientation": props.orientation,
        "__css": (0, _extends2["default"])({}, stylesRest, {
          border: 0,
          borderColor: borderColor,
          borderStyle: borderStyle
        }, dividerStyle.value),
        "__label": "divider"
      }, {
        "default": function _default() {
          return [slots["default"] == null ? void 0 : slots["default"]()];
        }
      });
    };
  }
});
exports.CDivider = CDivider;
//# sourceMappingURL=divider.js.map