"use strict";

exports.__esModule = true;
exports.CGridItem = exports.CGrid = void 0;

var _vue = require("vue");

var _vueSystem = require("@chakra-ui/vue-system");

var _utils = require("@chakra-ui/utils");

var _vueUtils = require("@chakra-ui/vue-utils");

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !(0, _vue.isVNode)(s);
}

/**
 * Vue component used to create grid layouts.
 *
 * It renders a `div` with `display: grid` and
 * comes with helpful style shorthand.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/grid
 */
var CGrid = (0, _vue.defineComponent)({
  name: 'CGrid',
  props: {
    as: {
      type: [String, Object],
      "default": 'div'
    },
    templateColumns: _vueUtils.SNAO,
    gap: _vueUtils.SNAO,
    rowGap: _vueUtils.SNAO,
    columnGap: _vueUtils.SNAO,
    autoFlow: _vueUtils.SNAO,
    autoRows: _vueUtils.SNAO,
    autoColumns: _vueUtils.SNAO,
    templateRows: _vueUtils.SNAO,
    templateAreas: _vueUtils.SNAO,
    area: _vueUtils.SNAO,
    column: _vueUtils.SNAO,
    row: _vueUtils.SNAO
  },
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    var styles = (0, _vue.computed)(function () {
      return (0, _utils.filterUndefined)({
        display: 'grid',
        gridArea: props.area,
        gridTemplateAreas: props.templateAreas,
        gridGap: props.gap,
        gridRowGap: props.rowGap,
        gridColumnGap: props.columnGap,
        gridAutoColumns: props.autoColumns,
        gridColumn: props.column,
        gridRow: props.row,
        gridAutoFlow: props.autoFlow,
        gridAutoRows: props.autoRows,
        gridTemplateRows: props.templateRows,
        gridTemplateColumns: props.templateColumns
      });
    });
    return function () {
      return (0, _vue.createVNode)(_vueSystem.chakra.div, (0, _vue.mergeProps)({
        "as": props.as,
        "__label": "grid",
        "__css": styles.value
      }, attrs), _isSlot(slots) ? slots : {
        "default": function _default() {
          return [slots];
        }
      });
    };
  }
});
exports.CGrid = CGrid;

function spanFn(span) {
  return (0, _utils.mapResponsive)(span, function (value) {
    return value === 'auto' ? 'auto' : "span " + value + "/span " + value;
  });
}

var CGridItem = (0, _vue.defineComponent)({
  name: 'CGridItem',
  props: {
    as: {
      type: [String, Object],
      "default": 'div'
    },
    colSpan: _vueUtils.SNAO,
    colStart: _vueUtils.SNAO,
    colEnd: _vueUtils.SNAO,
    rowStart: _vueUtils.SNAO,
    rowEnd: _vueUtils.SNAO,
    rowSpan: _vueUtils.SNAO
  },
  setup: function setup(props, _ref2) {
    var slots = _ref2.slots,
        attrs = _ref2.attrs;
    var styles = (0, _vue.computed)(function () {
      return (0, _utils.filterUndefined)({
        gridColumn: spanFn(props.colSpan),
        gridRow: spanFn(props.rowSpan),
        gridColumnStart: props.colStart,
        gridColumnEnd: props.colEnd,
        gridRowStart: props.rowStart,
        gridRowEnd: props.rowEnd
      });
    });
    return function () {
      return (0, _vue.createVNode)(_vueSystem.chakra.div, (0, _vue.mergeProps)({
        "as": props.as,
        "__label": "grid__item",
        "__css": styles.value
      }, attrs), _isSlot(slots) ? slots : {
        "default": function _default() {
          return [slots];
        }
      });
    };
  }
});
exports.CGridItem = CGridItem;
//# sourceMappingURL=grid.js.map