"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.CLink = void 0;

var _vue = require("vue");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _vueUtils = require("@chakra-ui/vue-utils");

var _vueSystem = require("@chakra-ui/vue-system");

var _utils = require("@chakra-ui/utils");

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !(0, _vue.isVNode)(s);
}

/**
 * Links are accessible elements used primarily for navigation.
 *
 * It integrates well with other routing libraries like
 * Vue Router and Nuxt.js Link.
 *
 * @example
 *
 * ```vue
 * <CLink as="router-link" to="/home">Home</CLink>
 * ```
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/link
 */
var CLink = (0, _vue.defineComponent)({
  name: 'CLink',
  props: (0, _extends2["default"])({
    as: {
      type: [Object, String],
      "default": 'a'
    },
    isExternal: Boolean
  }, _vueUtils.vueThemingProps),
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    var themingProps = (0, _vue.computed)(function () {
      return (0, _utils.filterUndefined)({
        colorScheme: props.colorScheme,
        variant: props.variant,
        size: props.size,
        styleConfig: props.styleConfig
      });
    });
    var styles = (0, _vueSystem.useStyleConfig)('Link', themingProps.value);
    return function () {
      return (0, _vue.createVNode)(_vueSystem.chakra.a, (0, _vue.mergeProps)({
        "as": props.as,
        "__label": "link",
        "target": props.isExternal ? '_blank' : undefined,
        "rel": props.isExternal ? 'noopener noreferrer' : undefined,
        "__css": styles.value
      }, attrs), _isSlot(slots) ? slots : {
        "default": function _default() {
          return [slots];
        }
      });
    };
  }
});
exports.CLink = CLink;
//# sourceMappingURL=link.js.map