"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.CListIcon = exports.CListItem = exports.CUnorderedList = exports.COrderedList = exports.CList = void 0;

var _vue = require("vue");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _cIcon = require("@chakra-ui/c-icon");

var _vueSystem = require("@chakra-ui/vue-system");

var _vueUtils = require("@chakra-ui/vue-utils");

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !(0, _vue.isVNode)(s);
}

/**
 * List is used to display list items, it renders a `<ul>` by default.
 *
 * @see Docs https://vue.chakra-ui.com/docs/data-display/list
 */
var CList = (0, _vue.defineComponent)({
  name: 'CList',
  props: {
    as: {
      type: [Object, String],
      "default": 'ul'
    },
    styleType: {
      type: _vueUtils.SAO,
      "default": 'none'
    },
    stylePosition: _vueUtils.SAO,
    spacing: _vueUtils.SNAO
  },
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    var styles = (0, _vueSystem.useMultiStyleConfig)('List', props);
    (0, _vueSystem.StylesProvider)(styles);
    var selector = '& > *:not(style) ~ *:not(style)';
    var spacingStyle = (0, _vue.computed)(function () {
      var _ref2;

      return props.spacing ? (_ref2 = {}, _ref2[selector] = {
        mt: props.spacing
      }, _ref2) : {};
    });
    return function () {
      var validChildren = function validChildren() {
        return (0, _vueUtils.getValidChildren)(slots);
      };

      return (0, _vue.createVNode)(_vueSystem.chakra.ul, (0, _vue.mergeProps)({
        "__label": "list",
        "as": props.as,
        "listStyleType": props.styleType,
        "listStylePosition": props.stylePosition,
        "role": "list",
        "__css": (0, _extends2["default"])({}, styles.value.container, spacingStyle.value)
      }, attrs), _isSlot(validChildren) ? validChildren : {
        "default": function _default() {
          return [validChildren];
        }
      });
    };
  }
});
exports.CList = CList;
var COrderedList = (0, _vue.defineComponent)({
  name: 'COrderedList',
  setup: function setup(props, _ref3) {
    var slots = _ref3.slots,
        attrs = _ref3.attrs;
    return function () {
      return (// @ts-ignore
        (0, _vue.createVNode)(CList, (0, _vue.mergeProps)({
          "styleType": "decimal",
          "marginStart": "1em"
        }, attrs), _isSlot(slots) ? slots : {
          "default": function _default() {
            return [slots];
          }
        })
      );
    };
  }
});
exports.COrderedList = COrderedList;
var CUnorderedList = (0, _vue.defineComponent)({
  name: 'CUnorderedList',
  setup: function setup(props, _ref4) {
    var slots = _ref4.slots,
        attrs = _ref4.attrs;
    return function () {
      return (// @ts-ignore
        (0, _vue.createVNode)(CList, (0, _vue.mergeProps)({
          "styleType": "initial",
          "marginStart": "1em"
        }, attrs), _isSlot(slots) ? slots : {
          "default": function _default() {
            return [slots];
          }
        })
      );
    };
  }
});
exports.CUnorderedList = CUnorderedList;
var CListItem = (0, _vue.defineComponent)({
  name: 'CListItem',
  setup: function setup(_, _ref5) {
    var slots = _ref5.slots,
        attrs = _ref5.attrs;
    var styles = (0, _vueSystem.useStyles)();
    return function () {
      return (0, _vue.createVNode)(_vueSystem.chakra.li, (0, _vue.mergeProps)({
        "__label": "list__item",
        "__css": styles.value.item
      }, attrs), _isSlot(slots) ? slots : {
        "default": function _default() {
          return [slots];
        }
      });
    };
  }
});
exports.CListItem = CListItem;
var CListIcon = (0, _vue.defineComponent)({
  name: 'CListIcon',
  setup: function setup(_, _ref6) {
    var slots = _ref6.slots,
        attrs = _ref6.attrs;
    var styles = (0, _vueSystem.useStyles)();
    return function () {
      return (// @ts-expect-error
        (0, _vue.createVNode)(_cIcon.CIcon, (0, _vue.mergeProps)({
          "role": "presentation"
        }, attrs, {
          "__css": styles.value.icon
        }), _isSlot(slots) ? slots : {
          "default": function _default() {
            return [slots];
          }
        })
      );
    };
  }
});
exports.CListIcon = CListIcon;
//# sourceMappingURL=list.js.map