import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";
import { mapResponsive } from '@chakra-ui/utils';
import { chakra } from '@chakra-ui/vue-system';
import { defineComponent } from 'vue';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

/**
 * Vue component used to cropping media (videos, images and maps)
 * to a desired aspect ratio.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/aspect-ratio
 */
export var CAspectRatio = defineComponent({
  name: 'CAspectRatio',
  props: {
    ratio: {
      type: [Number],
      default: 4 / 3
    }
  },

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    return () => _createVNode(chakra.div, _mergeProps({
      "__label": "aspect-ratio",
      "position": "relative",
      "_before": {
        height: 0,
        content: "\"\"",
        display: 'block',
        paddingBottom: mapResponsive(props.ratio, r => 1 / r * 100 + "%")
      },
      "__css": {
        '& > *:not(style)': {
          overflow: 'hidden',
          position: 'absolute',
          top: '0',
          right: '0',
          bottom: '0',
          left: '0',
          display: 'flex',
          justifyContent: 'center',
          alignItems: 'center',
          width: '100%',
          height: '100%'
        },
        '& > img, & > video': {
          objectFit: 'cover'
        }
      }
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});
//# sourceMappingURL=aspect-ratio.js.map