import _extends from "@babel/runtime/helpers/extends";
import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";
import { defineComponent, computed } from 'vue';
import { chakra, useStyleConfig } from '@chakra-ui/vue-system';
import { filterUndefined } from '@chakra-ui/utils';
import { vueThemingProps } from '@chakra-ui/vue-utils';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

/**
 * Vue component used to display notifications, messages, or
 * statuses in different shapes and sizes.
 *
 * @see Docs https://vue.chakra-ui.com/docs/data-display/badge
 */
export var CBadge = defineComponent({
  name: 'CBadge',
  props: _extends({
    as: {
      type: [Object, String],
      default: 'div'
    }
  }, vueThemingProps),

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    var themingProps = computed(() => filterUndefined({
      colorScheme: props.colorScheme,
      variant: props.variant,
      size: props.size,
      styleConfig: props.styleConfig
    }));
    var styles = useStyleConfig('Badge', themingProps.value);
    return () => {
      return _createVNode(chakra.div, _mergeProps({
        "as": props.as,
        "__label": "badge",
        "__css": _extends({
          display: 'inline-block',
          whiteSpace: 'nowrap',
          verticalAlign: 'middle'
        }, styles.value)
      }, attrs), _isSlot(slots) ? slots : {
        default: () => [slots]
      });
    };
  }

});
//# sourceMappingURL=badge.js.map