import _extends from "@babel/runtime/helpers/extends";
import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";
import { defineComponent, computed } from 'vue';
import { chakra, useStyleConfig } from '@chakra-ui/vue-system';
import { filterUndefined } from '@chakra-ui/utils';
import { vueThemingProps } from '@chakra-ui/vue-utils';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

/**
 * Layout component used to wrap app or website content
 *
 * It sets `margin-left` and `margin-right` to `auto`,
 * to keep its content centered.
 *
 * It also sets a default max-width of `60ch` (60 characters).
 */
export var CContainer = defineComponent({
  name: 'CContainer',
  props: _extends({
    as: {
      type: [Object, String],
      default: 'div'
    },
    centerContent: {
      type: [Boolean]
    }
  }, vueThemingProps),

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    var themingProps = computed(() => filterUndefined({
      colorScheme: props.colorScheme,
      variant: props.variant,
      size: props.size,
      styleConfig: props.styleConfig
    }));
    var styles = useStyleConfig('Container', themingProps.value);
    return () => _createVNode(chakra.div, _mergeProps({
      "__label": "container",
      "__css": _extends({}, styles.value, props.centerContent && {
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'center'
      })
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});
//# sourceMappingURL=container.js.map