import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/extends";
import { createVNode as _createVNode } from "vue";
import { defineComponent, computed } from 'vue';
import { chakra, useStyleConfig } from '@chakra-ui/vue-system';
import { filterUndefined } from '@chakra-ui/utils';
import { vueThemingProps } from '@chakra-ui/vue-utils';

/**
 * Layout component used to visually separate content in a list or group.
 * It display a thin horizontal or vertical line, and renders a `hr` tag.
 *
 * @see Docs https://vue.chakra-ui.com/docs/data-display/divider
 */
export var CDivider = defineComponent({
  name: 'CDivider',
  props: _extends({
    orientation: {
      type: [String],
      default: 'horizontal'
    }
  }, vueThemingProps),

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    var themingProps = computed(() => filterUndefined({
      colorScheme: props.colorScheme,
      variant: props.variant,
      size: props.size,
      styleConfig: props.styleConfig,
      orientation: props.orientation
    }));
    var styles = useStyleConfig('Divider', themingProps.value);

    var _styles$value = styles.value,
        {
      borderLeftWidth,
      borderBottomWidth,
      borderTopWidth,
      borderRightWidth,
      borderWidth,
      borderStyle,
      borderColor
    } = _styles$value,
        stylesRest = _objectWithoutPropertiesLoose(_styles$value, ["borderLeftWidth", "borderBottomWidth", "borderTopWidth", "borderRightWidth", "borderWidth", "borderStyle", "borderColor"]);

    var dividerStyle = computed(() => {
      var dividerStyles = {
        vertical: {
          borderLeftWidth: borderLeftWidth || borderRightWidth || borderWidth || '1px',
          height: '100%'
        },
        horizontal: {
          borderBottomWidth: borderBottomWidth || borderTopWidth || borderWidth || '1px',
          width: '100%'
        }
      };
      return dividerStyles[props.orientation];
    });
    return () => _createVNode(chakra.hr, {
      "aria-orientation": props.orientation,
      "__css": _extends({}, stylesRest, {
        border: 0,
        borderColor,
        borderStyle
      }, dividerStyle.value),
      "__label": "divider"
    }, {
      default: () => [slots.default == null ? void 0 : slots.default()]
    });
  }

});
//# sourceMappingURL=divider.js.map