import _extends from "@babel/runtime/helpers/extends";
import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";
import { vueThemingProps } from '@chakra-ui/vue-utils';
import { chakra, useStyleConfig } from '@chakra-ui/vue-system';
import { computed, defineComponent } from 'vue';
import { filterUndefined } from '@chakra-ui/utils';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

export var CHeading = defineComponent({
  name: 'CHeading',
  props: _extends({
    as: {
      type: [String, Object],
      default: 'h2'
    }
  }, vueThemingProps),

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    var themingProps = computed(() => filterUndefined({
      colorScheme: props.colorScheme,
      variant: props.variant,
      size: props.size,
      styleConfig: props.styleConfig
    }));
    var styles = useStyleConfig('Heading', themingProps.value);
    return () => _createVNode(chakra.h2, _mergeProps({
      "as": props.as,
      "__label": "heading",
      "__css": styles.value
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});
//# sourceMappingURL=heading.js.map