import _extends from "@babel/runtime/helpers/extends";
import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";
import { vueThemingProps } from '@chakra-ui/vue-utils';
import { chakra, useStyleConfig } from '@chakra-ui/vue-system';
import { computed, defineComponent } from '@vue/runtime-core';
import { filterUndefined } from '@chakra-ui/utils';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

/**
 * Semantic component to render a keyboard shortcut
 * within an application.
 *
 * @example
 *
 * ```jsx
 * <CKbd>⌘ + T</CKbd>
 * ```
 *
 * @see Docs https://vue.chakra-ui.com/docs/data-display/kbd
 */
export var CKbd = defineComponent({
  name: 'CKbd',
  props: _extends({
    as: {
      type: [String, Object],
      default: 'h2'
    }
  }, vueThemingProps),

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    var themingProps = computed(() => filterUndefined({
      colorScheme: props.colorScheme,
      variant: props.variant,
      size: props.size,
      styleConfig: props.styleConfig
    }));
    var styles = useStyleConfig('Kbd', themingProps.value);
    return () => _createVNode(chakra.kbd, _mergeProps({
      "__label": "kbd",
      "__css": _extends({
        fontFamily: 'mono'
      }, styles.value)
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});
//# sourceMappingURL=kbd.js.map