import { createVNode as _createVNode, isVNode as _isVNode } from "vue";
import { chakra } from '@chakra-ui/vue-system';
import { defineComponent } from '@vue/runtime-core';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

/**
 * A flexible flex spacer that expands along the major axis of its containing flex layout.
 * It renders a `div` by default, and takes up any available space.
 *
 * @see Docs https://chakra-ui.com/docs/layout/flex#using-the-spacer
 */
export var CSpacer = defineComponent({
  name: 'CSpacer',

  setup(_, _ref) {
    var {
      slots
    } = _ref;
    return () => {
      return _createVNode(chakra.div, {
        "__label": "spacer",
        "baseStyle": {
          flex: 1,
          justifySelf: 'stretch',
          alignSelf: 'stretch'
        }
      }, _isSlot(slots) ? slots : {
        default: () => [slots]
      });
    };
  }

});
//# sourceMappingURL=spacer.js.map