import { ComponentWithProps, HTMLChakraProps } from '@chakra-ui/vue-system';
import { ThemingProps, DeepPartial } from '@chakra-ui/vue-system';
export interface LinkProps extends HTMLChakraProps<'a'>, ThemingProps<'Link'> {
    /**
     *  If `true`, the link will open in new tab
     */
    isExternal?: boolean;
}
/**
 * Links are accessible elements used primarily for navigation.
 *
 * It integrates well with other routing libraries like
 * Vue Router and Nuxt.js Link.
 *
 * @example
 *
 * ```vue
 * <CLink as="router-link" to="/home">Home</CLink>
 * ```
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/link
 */
export declare const CLink: ComponentWithProps<DeepPartial<LinkProps>>;
