import { SystemProps } from '@chakra-ui/styled-system';
import { Component } from 'vue';
import { DeepPartial, HTMLChakraProps, ComponentWithProps } from '@chakra-ui/vue-system';
import { StackDirection } from './stack.utils';
interface StackOptions {
    /**
     * Shorthand for `alignItems` style prop
     * @type SystemStyleObject["alignItems"]
     */
    align?: SystemProps['alignItems'];
    /**
     * Shorthand for `justifyContent` style prop
     * @type SystemStyleObject["justifyContent"]
     */
    justify?: SystemProps['justifyContent'];
    /**
     * Shorthand for `flexWrap` style prop
     * @type SystemStyleObject["flexWrap"]
     */
    wrap?: SystemProps['flexWrap'];
    /**
     * The space between each stack item
     * @type SystemStyleObject["margin"]
     */
    spacing?: SystemProps['margin'];
    /**
     * The direction to stack the items.
     */
    direction?: StackDirection;
    /**
     * If `true`, each stack item will show a divider
     * @type Component | boolean
     */
    divider?: Component | boolean;
    /**
     * If `true`, the children will be wrapped in a `Box` with
     * `display: inline-block`, and the `Box` will take the spacing props
     */
    shouldWrapChildren?: boolean;
    /**
     * If `true` the items will be stacked horizontally.
     */
    isInline?: boolean;
}
export interface StackDividerProps extends HTMLChakraProps<'div'> {
}
export declare const CStackDivider: ComponentWithProps<DeepPartial<StackDividerProps>>;
export declare const CStackItem: ComponentWithProps<DeepPartial<HTMLChakraProps<'div'>>>;
export interface StackProps extends HTMLChakraProps<'div'>, StackOptions {
}
/**
 * Stacks help you easily create flexible and automatically distributed layouts
 *
 * You can stack elements in the horizontal or vertical direction,
 * and apply a space or/and divider between each element.
 *
 * It uses `display: flex` internally and renders a `div`.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/stack
 *
 */
export declare const CStack: ComponentWithProps<DeepPartial<StackProps>>;
/**
 * A view that arranges its children in a horizontal line.
 */
export declare const CHStack: ComponentWithProps<DeepPartial<StackProps>>;
/**
 * A view that arranges its children in a vertical line.
 */
export declare const CVStack: ComponentWithProps<DeepPartial<StackProps>>;
export {};
